MethodChannelWhatsappStickersHandler class

An implementation of WhatsappStickersHandlerPlatform that uses method channels.

Inheritance

Properties

hashCode int
The hash code for this object.
no setterinherited
isWhatsAppInstalled Future<bool>
Returns if WhatsApp is installed
no setteroverride
methodChannel MethodChannel
The method channel used to interact with the native platform.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addStickerPack(StickerPack stickerPack) Future<void>
Adds stickerPack to Whatsapp
override
deleteStickerPack(String identifier) Future<void>
Deletes StickerPack with identifier from the storage
override
isStickerPackInstalled(String identifier) Future<bool>
Checks if a StickerPack with the given identifier is available in WhatsApp
override
launchWhatsApp() → void
Launches WhatsApp
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
updateStickerPack(StickerPack stickerPack) Future<void>
Updates stickerPack in Whatsapp
override

Operators

operator ==(Object other) bool
The equality operator.
inherited