addStickerPack method

  1. @override
Future<void> addStickerPack(
  1. StickerPack stickerPack
)
override

Adds stickerPack to Whatsapp

Saves stickerPack to the sticker pack list that is exposed via the ContentProvider Does not save the actual sticker files anywhere Also sends request to add the pack to Whatsapp

Implementation

@override
Future<void> addStickerPack(StickerPack stickerPack) async {
  return await methodChannel.invokeMethod('addStickerPack', stickerPack.json);
}