deleteStickerPack method

  1. @override
Future<void> deleteStickerPack(
  1. String identifier
)
override

Deletes StickerPack with identifier from the storage

Deletes StickerPack from the sticker pack list that is exposed via the ContentProvider The StickerPack still needs to be deleted manually in the WhatsApp UI

Implementation

@override
Future<void> deleteStickerPack(String identifier) async {
  return await methodChannel.invokeMethod('deleteStickerPack', {
    'identifier': identifier,
  });
}