MethodChannelWhatsappStickersHandler class
An implementation of WhatsappStickersHandlerPlatform that uses method channels.
- Inheritance
-
- Object
- PlatformInterface
- WhatsappStickersHandlerPlatform
- MethodChannelWhatsappStickersHandler
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
isWhatsAppInstalled
→ Future<
bool> -
Returns if WhatsApp is installed
no setteroverride
- methodChannel → MethodChannel
-
The method channel used to interact with the native platform.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addStickerPack(
StickerPack stickerPack) → Future< void> -
Adds
stickerPackto Whatsappoverride -
deleteStickerPack(
String identifier) → Future< void> -
Deletes StickerPack with
identifierfrom the storageoverride -
isStickerPackInstalled(
String identifier) → Future< bool> -
Checks if a StickerPack with the given
identifieris available in WhatsAppoverride -
launchWhatsApp(
) → void -
Launches WhatsApp
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
updateStickerPack(
StickerPack stickerPack) → Future< void> -
Updates
stickerPackin Whatsappoverride
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited